@@ -5,6 +5,7 @@
 
 #include <stdlib.h>
 #include <string.h>
+#include <linux/atmclip.h>
 
 #include "atmd.h"
 
@@ -60,6 +61,10 @@ void itf_up(int number)
 	return;
     }
     itf->number = number;
+    memset(&itf->qos,0,sizeof(struct atm_qos));
+    itf->qos.txtp.traffic_class = ATM_UBR;
+    itf->qos.txtp.max_sdu = RFC1483LLC_LEN+RFC1626_MTU;
+    itf->qos.rxtp = itf->qos.txtp;
     itf->table = itf->arp_srv = NULL;
     Q_INSERT_HEAD(itfs,itf);
 }
