@@ -54,7 +54,8 @@ int main(int argc,char **argv)
 	qos.txtp.min_pcr = atoi(argv[2]);
     }
     qos.rxtp.traffic_class = ATM_UBR;
-    qos.txtp.max_sdu = qos.rxtp.max_sdu = RFC1626_MTU;
+    qos.txtp.max_sdu = qos.rxtp.max_sdu = RFC1626_MTU+
+      (null ? 0 : RFC1483LLC_LEN);
     if (setsockopt(s,SOL_ATM,SO_ATMQOS,&qos,sizeof(qos)) < 0) {
 	perror("setsockopt SO_ATMQOS");
 	return 1;
