@@ -56,7 +56,7 @@ static int lec_socket;
 static kernel_callback callback_funcs[ATMLEC_MSG_TYPE_MAX];
 
 int 
-kernel_init(unsigned char *mac_addr)
+kernel_init(unsigned char *mac_addr, int itf_num)
 {
   int rvalue;
   struct atmlec_msg msg;
@@ -67,8 +67,8 @@ kernel_init(unsigned char *mac_addr)
     EVENT(EM_SERR,("Socket creation failure:%s\n",strerror(errno)));
     return -1;
   }
-  rvalue = ioctl(lec_socket, ATMLEC_CTRL);
-  if (rvalue <0) {
+  itf_num = ioctl(lec_socket, ATMLEC_CTRL, itf_num);
+  if (itf_num <0) {
     EVENT(EM_SERR,("Socket ioctl to lecd_ctrl failed:%s\n", strerror(errno)));
     close(lec_socket);
     return -1;
@@ -104,7 +104,7 @@ kernel_init(unsigned char *mac_addr)
     return -1;
   }
   /* Add fd to select */
-  return 0;
+  return itf_num;
 }
 
 int 
@@ -156,8 +156,6 @@ get_mesg_type_str(atmlec_msg_type type)
     return "SVC_SETUP";
   case l_arp_xmt:
     return "ARP_XMT";
-  case l_add_permanent:
-    return "ADD_PERMANENT";
   case l_addr_delete:
     return "ADDR_DELETE";
   case l_topology_change:
@@ -166,8 +164,6 @@ get_mesg_type_str(atmlec_msg_type type)
     return "FLUSH_COMPLETE";
   case l_arp_update:
     return "ARP_UPDATE";
-  case l_reset:
-    return "RESET";
   case l_config:
     return "CONFIG";
   default:
