@@ -74,7 +74,6 @@
 *     - la_register
 *       - la_config
 *         - la_arp_resolve
-*         - la_perm_add
 *         - la_addr_delete
 *         - la_arp_update
 *         - la_flush_complete
@@ -100,10 +99,6 @@
 *                           made once the configuration phase of the join is
 *                           complete and the parameters are known.
 *
-*   la_perm_add.............Permanent addresses may be added to the cache by
-*                           local or remote (via SNMP) network management
-*                           applications.
-*
 *   la_arp_resolve..........This is called each time a transmit data packet is
 *                           sent by the protocol.  In this case, the
 *                           destination MAC address is not in the LE-ARP cache
@@ -471,39 +466,6 @@ void la_config (HANDLE     la_elan_handle,
 --*/
 void la_elan_reset (HANDLE   la_elan_handle);
 
-/*++
-* ===============
-* = la_perm_add =
-* ===============
-*
-* Overview:
-*   Add a permanent LE-ARP cache entry.  Such an entry does not age and is
-*   kept until this ELAN instance is deregietered via la_deregister.
-*   Permanent LE-ARP cache entries are added and deleted at the request of
-*   network management software.
-*
-* Arguments:
-*   la_elan_handle  - (IN) Handle returned by la_register.
-*   esi             - (IN) MAC address of the permanent entry.
-*   addr_atm        - (IN) ATM address related to the MAC address.
-*
-* Returns:
-*   STATUS_K_SUCCESS    - Successful Completion, see postconditions.
-*   STATUS_K_RESOURCES  - Insufficient resources to complete operation.
-*   STATUS_K_BUSY       - A matching permanent address is already in the cache.
-*
-* Preconditions:
-*   None
-*
-* Postconditions:
-*   There is a permanent address with the requested mapping in the LE-ARP
-*   cache.  If there was a non-permanent entry with the requested MAC address,
-*   that entry is overwritten with the new permanent entry.
---*/
-STATUS la_perm_add (HANDLE    la_elan_handle,
-                    ESI       esi,
-                    ADDR_ATM  addr_atm);
-
 /*++
 * ==================
 * = la_addr_delete =
