@@ -45,11 +45,14 @@
 
 #define ATM_IE_CAUSE		0x08 /* Cause */
 #define ATM_IE_CALL_STATE	0x14 /* Call state */
+#define ATM_IE_NOTIFY		0x27 /* Notification indicator */
+#define ATM_IE_E2E_TD		0x42 /* End-to-end transit delay */
 #define ATM_IE_EPR		0x54 /* Endpoint reference */
 #define ATM_IE_EP_STATE		0x55 /* Endpoint state */
 #define ATM_IE_AAL		0x58 /* ATM adaption layer parameters */
 #define ATM_IE_TD		0x59 /* ATM traffic descriptor */
 #define ATM_IE_CONN_ID		0x5a /* Connection identifier */
+#define ATM_IE_OAM_TD		0x5b /* OAM traffic descriptor */
 #define ATM_IE_QOS		0x5c /* Quality of service parameter */
 #define ATM_IE_BHLI		0x5d /* Broadband high layer information */
 #define ATM_IE_BBCAP		0x5e /* Broadband bearer capability */
@@ -301,6 +304,44 @@
 #define ATM_AALP_AAL_MODE	0x83 /* AAL mode (UNI 3.0 only) */
 #define ATM_AALP_SSCS		0x84 /* SSCS type */
 
+/* Transit delay identifiers */
+
+#define ATM_TDL_CUM		0x01 /* Cumulative transit delay value */
+#define ATM_TDL_E2EMAX		0x03 /* Maximum end-to-end transit delay value*/
+
+/* Transit network identification */
+
+#define ATM_TNI_USER		0x00 /* User-specified */
+#define ATM_TNI_NNI		0x02 /* National network identification */
+#define ATM_TNI_INI		0x04 /* International network identification */
+
+/* Network identification plan */
+
+#define ATM_NIP_UNKNOWN		0x00 /* Unknown */
+#define ATM_NIP_CARRIER		0x01 /* Carrier identification code */
+#define ATM_NIP_DATA		0x03 /* Data network id. code (X.121) */
+
+/* Shaping indicator */
+
+#define ATM_SHI_NONE		0x00 /* No user specified requirement */
+#define ATM_SHI_NOAGG		0x01 /* Aggr. shaping of user & OAM not all. */
+
+/* Compliance indicator */
+
+#define ATM_OCI_OPT		0x00 /* Use of e2e OAM F5 flow is optional */
+#define ATM_OCI_MAND		0x01 /* Use of e2e OAM F5 flow is mandatory */
+
+/* User-network fault management indicator */
+
+#define ATM_UNFM_NONE		0x00 /* No user-orig. fault mg. indications */
+#define ATM_UNFM_1CPS		0x01 /* Use of u-o fm. ind. w/ rate 1 cps */
+
+/* End-to-end OAM F5 flow indicator */
+
+#define ATM_OFI_0_0		0x00 /* 0% of cell rate (CLP=0+1) in ATM TD */
+#define ATM_OFI_0_1		0x01 /* 0.1% of cell rate (CLP=0+1) in ATM TD */
+#define ATM_OFI_1_0		0x04 /* 1% of cell rate (CLP=0+1) in ATM TD */
+
 /* The following constants tag message parser errors. */
 
 #define RECOV_IND_IE		1	/* IE problem */
