@@ -222,6 +222,8 @@ void q_assign(Q_DSC *dsc,int field,unsigned long value)
     if (field < 0 || field >= Q_FIELDS)
 	q_report(Q_FATAL,"invalid field value (%d)",field);
     if (!fields[field].values) {
+	if (q_test(dsc->field_present,field)) /* probably an error ... */
+	    q_report(Q_ERROR,"changing field %d",field);
 	q_set(dsc->field_present,field);
 	q_put(dsc->data,fields[field].pos,fields[field].size,value);
 	use_group(dsc,fields[field].parent);
