@@ -34,6 +34,20 @@ extern void qd_dump(const char *fmt,...);
 #endif
 
 
+typedef enum { qet_catch_zero,qet_space,qet_case,qet_abort } Q_ERR_TYPE;
+
+typedef struct _q_err_dsc {
+    Q_ERR_TYPE type; /* error type code */
+    int pc; /* PC when error was discovered */
+    int offset; /* offset into message when error was discovered */
+    int value; /* additional value (optional) */
+    int id; /* user-assigned id */
+    int start; /* recovery area */
+    int length;
+    int group; /* group that failed (for fixups) */
+    struct _q_err_dsc *next;
+} Q_ERR_DSC;
+
 typedef struct {
     unsigned char *data;
     unsigned char *required;
@@ -43,9 +57,10 @@ typedef struct {
     void *buffer;
     int buf_size;
     int error;
+    Q_ERR_DSC *errors;
 } Q_DSC;
  
- 
+
 void PREFIX(start)(void);
 int PREFIX(open)(Q_DSC *dsc,void *buf,int size);
 int q_create(Q_DSC *dsc,void *buf,int size);
