@@ -10,6 +10,7 @@
 #include "file.h"
 
 
+int sym_tables = 0,symbols = 0;
 static int unique;
 
 
@@ -43,6 +44,7 @@ static void find_required(FIELD *start)
 	if (walk->value) 
 	    switch  (walk->value->type) {
 		case vt_id:
+		    break;
 		case vt_case:
 		case vt_multi:
 		    for (scan = walk->value->tags; scan; scan = scan->next)
@@ -175,34 +177,55 @@ static void fields(FIELD *start,int group)
 static void symbolic_names(FIELD *start)
 {
     FIELD *walk;
+    NAME *name;
     TAG *scan;
     VALUE_LIST *tag;
 
     for (walk = start; walk; walk = walk->next) {
-	if (walk->value) {
-	    to_dump("static SYM_NAME dump_sym_%d[] = {\n",walk->seq);
-	    switch  (walk->value->type) {
-		case vt_id:
-		    to_dump("    { %s, \"%s\" },\n",walk->value->id,
-		      walk->value->id);
-		    break;
-		case vt_case:
-		case vt_multi:
-		    for (scan = walk->value->tags; scan; scan = scan->next) {
-			to_dump("    { %s, \"%s\" },\n",scan->value,
-			  scan->value);
-			for (tag = scan->more; tag; tag = tag->next)
-			    to_dump("    { %s, \"%s\" },\n",tag->value,
-			      tag->value);
-		    }
-		    break;
-		case vt_length:
-		    break;
-		default:
-		    abort();
+	if (walk->name_list ? walk->name_list->id == -1 : !!walk->value) {
+	    if (walk->name_list) {
+		to_dump("static SYM_NAME dump_sym_%d[] = { /* %s */\n",
+		  walk->seq,walk->name_list->list_name);
+		sym_tables++;
+		walk->name_list->id = walk->seq;
+		for (name = walk->name_list->list; name; name = name->next) {
+		    to_dump("    { %s, \"%s\" },\n",name->value,name->name);
+		    symbols++;
+		}
+	    }
+	    else {
+		to_dump("static SYM_NAME dump_sym_%d[] = {\n",walk->seq);
+		sym_tables++;
+		switch (walk->value->type) {
+		    case vt_id:
+			to_dump("    { %s, \"%s\" },\n",walk->value->id,
+			  walk->value->id);
+			symbols++;
+			break;
+		    case vt_case:
+		    case vt_multi:
+			for (scan = walk->value->tags; scan; scan = scan->next)
+			  {
+			    to_dump("    { %s, \"%s\" },\n",scan->value,
+			      scan->value);
+			    symbols++;
+			    for (tag = scan->more; tag; tag = tag->next) {
+				to_dump("    { %s, \"%s\" },\n",tag->value,
+				  tag->value);
+				symbols++;
+			    }
+			}
+			break;
+		    case vt_length:
+			break;
+		    default:
+			abort();
+		}
 	    }
 	    to_dump("    { 0, NULL }\n};\n\n");
-	    switch  (walk->value->type) {
+	}
+	if (walk->value)
+	    switch (walk->value->type) {
 		case vt_id:
 		    break;
 		case vt_case:
@@ -216,7 +239,6 @@ static void symbolic_names(FIELD *start)
 		default:
 		    abort();
 	    }
-	}
     }
 }
 
