@@ -707,13 +707,13 @@ static void set_data_transfer_timers(SSCOP_DSC *dsc) /* 20.51 */
 
 static void initialize_vr_mr(SSCOP_DSC *dsc)
 {
-    dsc->vr_mr = SSCOP_CF_MR; /* was MOD24(dsc->vr_h+SSCOP_CF_MR); */
+    dsc->vr_mr = SSCOP_CF_MR;
 }
 
 
 static void update_vr_mr(SSCOP_DSC *dsc)
 {
-    initialize_vr_mr(dsc);
+    dsc->vr_mr = MOD24(dsc->vr_r+SSCOP_CF_MR);
 }
 
 
@@ -954,6 +954,7 @@ static void data_sd(SSCOP_DSC *dsc,int s,void *msg,int length) /* 20.38-39 */
 	}
 	while (1) {
 	    INC24(dsc->vr_r);
+	    update_vr_mr(dsc);
 	    buf = queue_lookup(&dsc->rx_buf,dsc->vr_r);
 	    if (!buf) break;
 	    queue_remove(&dsc->rx_buf,buf);
@@ -968,14 +969,12 @@ static void data_sd(SSCOP_DSC *dsc,int s,void *msg,int length) /* 20.38-39 */
     if (s == dsc->vr_h) {
 	queue_put(&dsc->rx_buf,buf);
 	INC24(dsc->vr_h);
-	update_vr_mr(dsc);
 	return;
     }
     if (NORM_RX(dsc->vr_h) < NORM_RX(s)) {
 	queue_put(&dsc->rx_buf,buf);
 	send_ustat(dsc,dsc->vr_h,s);
 	dsc->vr_h = MOD24(s+1);
-	update_vr_mr(dsc);
 	return;
     }
     if (queue_lookup(&dsc->rx_buf,s)) queue_put(&dsc->rx_buf,buf);
@@ -1002,7 +1001,6 @@ static void data_poll(SSCOP_DSC *dsc,int s) /* 20.41-42 */
 	return;
     }
     dsc->vr_h = NORM_RX(dsc->vr_mr) < NORM_RX(s) ? dsc->vr_mr : s;
-    update_vr_mr(dsc);
     /* K */
     curr = 0;
     i = dsc->vr_r;
