@@ -6,9 +6,11 @@
 #ifndef SAP_H
 #define SAP_H
 
-#include <linux/atmsap.h>
 #include <linux/atmsvc.h>
 
+#include "atmsap.h"
+
+
 int sap_check_packing(const struct sockaddr_atmsvc *packed_sap,int len);
 struct sockaddr_atmsvc *sap_copy(const struct sockaddr_atmsvc *sap);
 int sap_compat(const struct sockaddr_atmsvc *old_sap,
