@@ -135,12 +135,19 @@ Common options:\n\
 	-d	set SO_DEBUG socket option\n\
 	-b ##	set socket buffer size (if supported)\n\
 	-f X	format for rate: k,K = kilo{bit,byte}; m,M = mega; g,G = giga\n\
+	-a	use native ATM instead of UDP/TCP\n\
 Options specific to -t:\n\
 	-n##	number of source bufs written to network (default 2048)\n\
 	-D	don't buffer TCP writes (sets TCP_NODELAY socket option)\n\
+	-C	disable (UDP) checksums\n\
+	-P X	use the specified QOS for the ATM connection. If X is only\n\
+		a number, the following QOS spec is assumed: cbr:pcr=X\n\
+	-Q X	establish an Arequipa connection to ATM destination X\n\
 Options specific to -r:\n\
 	-B	for -s, only output full blocks as specified by -l (for TAR)\n\
 	-T	\"touch\": access each byte as it's read\n\
+	-Q X	enable acceptance of incoming Arequipa connections\n\
+		X can be any word.\n\
 ";	
 
 char stats[128];
